import type { ShaderMotionParams } from '../shader-mount.js';
import { type ShaderSizingParams, type ShaderSizingUniforms } from '../shader-sizing.js';
/**
 *
 * Fluid motion imitation applied over abstract shapes
 * (animated stripe pattern getting distorted with shape edges)
 *
 * Uniforms:
 * - u_colorBack, u_colorTint (RGBA)
 * - u_repetition: density of pattern stripes
 * - u_softness: blur between stripes
 * - u_shiftRed & u_shiftBlue: color dispersion between the stripes
 * - u_distortion: pattern distortion on the whole canvas
 * - u_contour: distortion power over the shape edges
 * - u_shape (float used as integer):
 * ---- 0: canvas-screen rectangle, needs u_worldWidth = u_worldHeight = 0 to be responsive (see vertex shader)
 * ---- 1: static circle
 * ---- 2: animated flower-like polar shape
 * ---- 3: animated metaballs
 *
 */
export declare const liquidMetalFragmentShader: string;
export interface LiquidMetalUniforms extends ShaderSizingUniforms {
    u_colorBack: [number, number, number, number];
    u_colorTint: [number, number, number, number];
    u_softness: number;
    u_repetition: number;
    u_shiftRed: number;
    u_shiftBlue: number;
    u_distortion: number;
    u_contour: number;
    u_shape: (typeof LiquidMetalShapes)[LiquidMetalShape];
}
export interface LiquidMetalParams extends ShaderSizingParams, ShaderMotionParams {
    colorBack?: string;
    colorTint?: string;
    softness?: number;
    repetition?: number;
    shiftRed?: number;
    shiftBlue?: number;
    distortion?: number;
    contour?: number;
    shape?: LiquidMetalShape;
}
export declare const LiquidMetalShapes: {
    readonly none: 0;
    readonly circle: 1;
    readonly daisy: 2;
    readonly metaballs: 3;
};
export type LiquidMetalShape = keyof typeof LiquidMetalShapes;
