import type { vec4 } from '../types.js';
import type { ShaderMotionParams } from '../shader-mount.js';
import { type ShaderSizingParams, type ShaderSizingUniforms } from '../shader-sizing.js';
export declare const pulsingBorderMeta: {
    readonly maxColorCount: 5;
    readonly maxSpotsPerColor: 5;
};
/**
 * Color spots traveling around rectangular stroke (border)
 *
 * Uniforms:
 * - u_colorBack (RGBA)
 * - u_colors (vec4[]), u_colorsCount (float used as integer)
 * - u_roundness, u_thickness, u_softness: border parameters
 * - u_intensity: global multiplier for spots shape & color
 * - u_spotSize: angular size of spots
 * - u_spotsPerColor (float used as int): number of spots rendered per color (not all visible at the same time)
 * - u_pulse: optional pulsing animation
 * - u_smoke, u_smokeSize: optional noisy shapes around the border
 *
 * - u_pulseTexture (sampler2D): pulsing signal source
 * - u_noiseTexture (sampler2D): pre-computed randomizer source
 *
 */
export declare const pulsingBorderFragmentShader: string;
export interface PulsingBorderUniforms extends ShaderSizingUniforms {
    u_colorBack: [number, number, number, number];
    u_colors: vec4[];
    u_colorsCount: number;
    u_roundness: number;
    u_thickness: number;
    u_softness: number;
    u_intensity: number;
    u_spotsPerColor: number;
    u_spotSize: number;
    u_pulse: number;
    u_smoke: number;
    u_smokeSize: number;
    u_pulseTexture?: HTMLImageElement;
}
export interface PulsingBorderParams extends ShaderSizingParams, ShaderMotionParams {
    colorBack?: string;
    colors?: string[];
    roundness?: number;
    thickness?: number;
    softness?: number;
    intensity?: number;
    spotsPerColor?: number;
    spotSize?: number;
    pulse?: number;
    smoke?: number;
    smokeSize?: number;
}
